#
# spec file for package gnome-tour
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global rustflags '-Clink-arg=-Wl,-z,relro,-z,now'

Name:           gnome-tour
Version:        47.0
Release:        1.2
Summary:        GNOME Tour & Greeter
License:        GPL-3.0-or-later
Group:          System/GUI/GNOME
URL:            https://gitlab.gnome.org/GNOME/gnome-tour
Source0:        %{name}-%{version}.tar.zst
Source2:        vendor.tar.zst

BuildRequires:  appstream-glib
BuildRequires:  cargo-packaging
BuildRequires:  desktop-file-utils
BuildRequires:  meson
BuildRequires:  pkgconfig(gio-2.0) >= 2.56
BuildRequires:  pkgconfig(glib-2.0) >= 2.64
BuildRequires:  pkgconfig(gtk4) >= 4.4
BuildRequires:  pkgconfig(libadwaita-1) >= 1

%description
A guided tour and greeter for GNOME.

%lang_package

%prep
%autosetup -p1 -a2

%build
export RUSTFLAGS=%{rustflags}
%meson \
	-D profile=default \
	%{nil}
%meson_build

%install
export RUSTFLAGS=%{rustflags}
%meson_install
%find_lang %{name} %{?no_lang_C}

%check
%meson_test
%cargo_test

%files
%license LICENSE.md
%doc README.md
%{_bindir}/gnome-tour
%{_datadir}/applications/org.gnome.Tour.desktop
%{_datadir}/icons/hicolor/scalable/apps/*
%{_datadir}/icons/hicolor/symbolic/apps/*
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/resources.gresource
%{_datadir}/metainfo/org.gnome.Tour.metainfo.xml

%files lang -f %{name}.lang

%changelog
* Mon Sep 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 47.0:
  + Updated translations.
- Drop no longer used pkgconfig(gdk-pixbuf-2.0) BuildRequires.
* Fri Mar 15 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.0:
  + Updated translations.
* Mon Mar  4 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.rc:
  + String improvements.
  + Updated translations.
* Sun Sep 17 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.0:
  + paginator: Use AdwToolbarView, subclass AdwBin
  + Update dependencies.
  + Updated translations.
- Switch compression to zst, both in service and tarball produced.
* Fri Mar 31 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add _constraints file, set minimum hdd to 5 gig.
* Mon Mar 20 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Switch to cargo_packaging:
  + Drop cargo and rust BuildRequires, add cargo-packaging
    BuildRequires and macros.
  + Use source services to generate tarball + run cargo packaging.
* Mon Mar 20 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.0:
  + No upstream changes provided.
* Tue Sep 20 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.0:
  + Updated translations.
* Sun Aug  7 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.beta:
  + Updated translations.
* Sun Mar 20 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.0:
  + Updated translations.
* Mon Feb 14 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.beta:
  + Port to GTK4 / libadwaita.
  + Drop the video feature.
  + Updated translations.
- Replace pkgconfig(gtk+-3.0) and pkgconfig(libhandy-1) with
  pkgconfig(gtk4) and pkgconfig(libadwaita-1) BuildRequires.
- Add appstream-glib and desktop-file-utils BuilRequires and add a
  check section, run meson_test macro.
- Pass profile=default to meson, we want to use the default build
  profile and not the development one.
* Mon Sep  6 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 41.rc:
  + Content: add back workspaces slide.
  + Add assets for GNOME 41.
  + Desktop: Add categories.
  + Updated translations.
* Wed Mar 24 2021 Florian <sp1ritCS@protonmail.com>
- Update to 40.0
  + Adapt the pages for GNOME Shell changes
  + Translation updates
* Tue Feb 16 2021 Callum Farmer <gmbr3@opensuse.org>
- Initial packaging version 40.beta
